import { Type } from "@infragistics/igniteui-react-core";
/**
 * Describes mode for selecting marker type when the series marker type is set to automatic.
 */
export declare enum MarkerAutomaticBehavior {
    /**
     * Sets a circle marker on most series and no marker on bar, column, waterfall, polygon, and step series.
     */
    CircleSmart = 0,
    /**
     * Sets no visible marker on all series in the chart.
     */
    None = 1,
    /**
     * Sets an marker on most series based on its index and no marker on bar, column, waterfall, polygon, and step series.
     */
    SmartIndexed = 2,
    /**
     * Sets marker for each series in the chart based on its index: circle, triangle, pyramid, etc.
     */
    Indexed = 3,
    /**
     * Sets circle marker on all series in the chart.
     */
    Circle = 4,
    /**
     * Sets flat-top triangle marker on all series in the chart.
     */
    Triangle = 5,
    /**
     * Sets flat-base triangle marker on all series in the chart.
     */
    Pyramid = 6,
    /**
     * Sets square marker shape on all series in the chart.
     */
    Square = 7,
    /**
     * Sets diamond marker on all series in the chart.
     */
    Diamond = 8,
    /**
     * Sets pentagon marker on all series in the chart.
     */
    Pentagon = 9,
    /**
     * Sets Hexagon marker on all series in the chart.
     */
    Hexagon = 10,
    /**
     * Sets four-pointed star marker on all series in the chart.
     */
    Tetragram = 11,
    /**
     * Sets five-pointed star marker on all series in the chart.
     */
    Pentagram = 12,
    /**
     * Sets six-pointed star marker on all series in the chart.
     */
    Hexagram = 13
}
/**
 * @hidden
 */
export declare let MarkerAutomaticBehavior_$type: Type;
