import { Type } from "@infragistics/igniteui-react-core";
/**
 * Describes available modes for searching for items in the scatter series.
 */
export declare enum ScatterItemSearchMode {
    /**
     * Search mode is automatically determined by the component.
     */
    Auto = 0,
    /**
     * When searching for a point, the closest visible point is selected.
     */
    ClosestVisiblePoint = 1,
    /**
     * When searching for a point, the closest point is selected, whether visible or not.
     * The search is skipped in performance critical scenarios if the number of points is over ItemSearchThreshold.
     */
    ClosestPoint = 2,
    /**
     * When searching for a point, the closest visible point along the closest visible line is used.
     * The search is skipped if the visible line points are over ItemSearchThreshold.
     */
    ClosestVisiblePointOnClosestLine = 3,
    /**
     * When searching for a point, the closest point along the closest line is used.
     * The search is skipped if the line points are over ItemSearchThreshold.
     */
    ClosestPointOnClosestLine = 4,
    /**
     * No points will be searched for the in the scatter series.
     */
    None = 5
}
/**
 * @hidden
 */
export declare let ScatterItemSearchMode_$type: Type;
