import { AxisRangeChangedEventArgs as AxisRangeChangedEventArgs_internal } from "./AxisRangeChangedEventArgs";
import { ContentChildrenManager } from "@infragistics/igniteui-react-core";
/**
 * Provides data for Axis RangeChanged events.
*
* The `AxisRangeChangedEventArgs` event fire when the axis range changes.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
* 		<IgrCategoryXAxis name="xAxis" label="Date" />
* 		<IgrNumericYAxis  name="yAxis" rangeChanaged={this.yAxisRangeChanged} />
*     <IgrFinancialPriceSeries
* 		name="series2"
* 		xAxisName="xAxis"
* 		yAxisName="yAxis"
* 		displayType="Candlestick"
* 		lowMemberPath="Low"
* 		highMemberPath="High"
* 		openMemberPath="Open"
* 		closeMemberPath="Close"
* 		volumeMemberPath="Volume" />
*  </IgrDataChart>
* ```
*
* ```ts
*   axis.rangeChanged.bind(this.yAxisRangeChanged);
*   public yAxisRangeChanged(sender : any, e: AxisRangeChangedEventArgs) =>  {
*
*    }
* ```
*/
export declare class IgrAxisRangeChangedEventArgs {
    protected createImplementation(): AxisRangeChangedEventArgs_internal;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): AxisRangeChangedEventArgs_internal;
    private onImplementationCreated;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * Gets the minimum value before the range changed. The reported minimum is the effective,
     * not the set value.
    *
    * The `OldMinimumValue` property is used to gets the minimum value before the range changed.
    */
    get oldMinimumValue(): number;
    set oldMinimumValue(v: number);
    /**
     * Gets the minimum value after the range changed. The reported minimum is the effective,
     * not the set value.
    *
    * The `MinimumValue` property is used to getsthe minimum value after the range changed.
    *
    * ```ts
    *   public yAxisRangeChanged(sender : any, e: AxisRangeChangedEventArgs) :void {
    * 	let maxVal= e.maximumValue
    * 	let minVal= e.minimumValue
    *
    *     }
    * ```
    */
    get minimumValue(): number;
    set minimumValue(v: number);
    /**
     * Gets the maximum value before the range changed. The reported maximum is the effective,
     * not the set value.
    *
    * The `OldMaximumValue` property is used to gets the maximum value before the range changed.
    */
    get oldMaximumValue(): number;
    set oldMaximumValue(v: number);
    /**
     * Gets the maximum value after the range changed. The reported maximum is the effective,
     * not the set value.
    *
    * The `MaximumValue` property is used to gets the maximum value after the range changed.
    *
    * ```ts
    *   public yAxisRangeChanged(sender : any, e: AxisRangeChangedEventArgs) :void {
    * 	let maxVal= e.maximumValue
    * 	let minVal= e.minimumValue
    *
    *     }
    * ```
    */
    get maximumValue(): number;
    set maximumValue(v: number);
}
