import { IgDataTemplate } from "@infragistics/igniteui-react-core";
import { IgrStyle } from "@infragistics/igniteui-react-core";
import { MarkerType } from "./MarkerType";
import { CollisionAvoidanceType } from "./CollisionAvoidanceType";
import { MarkerOutlineMode } from "./MarkerOutlineMode";
import { MarkerFillMode } from "./MarkerFillMode";
import { IgrShapeSeriesBase, IIgrShapeSeriesBaseProps } from "./igr-shape-series-base";
import { ScatterPolygonSeries } from "./ScatterPolygonSeries";
/**
 * Series class which renders polygons as Paths based on lists of points in the ItemsSource.
*/
export declare class IgrScatterPolygonSeries extends IgrShapeSeriesBase<IIgrScatterPolygonSeriesProps> {
    protected createImplementation(): ScatterPolygonSeries;
    /**
                                 * @hidden
                                 */
    get i(): ScatterPolygonSeries;
    constructor(props: IIgrScatterPolygonSeriesProps);
    /**
     * Gets whether the current series shows a polygon shape.
    */
    get isPolygon(): boolean;
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred(): boolean;
    /**
     * Returns whether the current series supports visual markers.
    */
    get hasMarkers(): boolean;
    /**
     * The default style to apply to all Shapes in the series.
    */
    get shapeStyle(): IgrStyle;
    set shapeStyle(v: IgrStyle);
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    get markerType(): MarkerType;
    set markerType(v: MarkerType);
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    get markerTemplate(): IgDataTemplate;
    set markerTemplate(v: IgDataTemplate);
    /**
     * Gets or sets thickness of the marker outline
    */
    get markerThickness(): number;
    set markerThickness(v: number);
    /**
     * Gets the effective marker template for the current series object.
    */
    get actualMarkerTemplate(): IgDataTemplate;
    set actualMarkerTemplate(v: IgDataTemplate);
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    get markerBrush(): string;
    set markerBrush(v: string);
    /**
     * Gets the effective marker brush for the current series object.
    */
    get actualMarkerBrush(): string;
    set actualMarkerBrush(v: string);
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    get markerOutline(): string;
    set markerOutline(v: string);
    /**
     * Gets the effective marker outline for the current series object.
    */
    get actualMarkerOutline(): string;
    set actualMarkerOutline(v: string);
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    get markerCollisionAvoidance(): CollisionAvoidanceType;
    set markerCollisionAvoidance(v: CollisionAvoidanceType);
    /**
     * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
    */
    get markerOutlineMode(): MarkerOutlineMode;
    set markerOutlineMode(v: MarkerOutlineMode);
    /**
     * Gets or sets whether the marker fill is based on the marker outline of the series rather than the marker brushes collection.
    */
    get markerFillMode(): MarkerFillMode;
    set markerFillMode(v: MarkerFillMode);
    findByName(name: string): any;
}
export interface IIgrScatterPolygonSeriesProps extends IIgrShapeSeriesBaseProps {
    /**
     * The default style to apply to all Shapes in the series.
    */
    shapeStyle?: IgrStyle;
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    markerType?: MarkerType | string;
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    markerTemplate?: IgDataTemplate;
    /**
     * Gets or sets thickness of the marker outline
    */
    markerThickness?: number | string;
    /**
     * Gets the effective marker template for the current series object.
    */
    actualMarkerTemplate?: IgDataTemplate;
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    markerBrush?: string;
    /**
     * Gets the effective marker brush for the current series object.
    */
    actualMarkerBrush?: string;
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    markerOutline?: string;
    /**
     * Gets the effective marker outline for the current series object.
    */
    actualMarkerOutline?: string;
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    markerCollisionAvoidance?: CollisionAvoidanceType | string;
    /**
     * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
    */
    markerOutlineMode?: MarkerOutlineMode | string;
    /**
     * Gets or sets whether the marker fill is based on the marker outline of the series rather than the marker brushes collection.
    */
    markerFillMode?: MarkerFillMode | string;
}
