import { IgPoint } from "@infragistics/igniteui-react-core";
import { IgrVerticalStackedSeriesBase, IIgrVerticalStackedSeriesBaseProps } from "./igr-vertical-stacked-series-base";
import { StackedBarSeries } from "./StackedBarSeries";
/**
 * Represents a IgxDataChartComponent stacked bar series.
*/
export declare class IgrStackedBarSeries<P extends IIgrStackedBarSeriesProps = IIgrStackedBarSeriesProps> extends IgrVerticalStackedSeriesBase<P> {
    protected createImplementation(): StackedBarSeries;
    /**
                                 * @hidden
                                 */
    get i(): StackedBarSeries;
    constructor(props: P);
    /**
     * Gets whether the current series shows a bar shape.
    */
    get isBar(): boolean;
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred(): boolean;
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
    */
    get radiusX(): number;
    set radiusX(v: number);
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
    */
    get radiusY(): number;
    set radiusY(v: number);
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item: any): boolean;
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan(): number;
}
export interface IIgrStackedBarSeriesProps extends IIgrVerticalStackedSeriesBaseProps {
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
    */
    radiusX?: number | string;
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
    */
    radiusY?: number | string;
}
